-- pessoa
CREATE TABLE pessoa (
  id_pessoa   SERIAL PRIMARY KEY,
  nome        VARCHAR(50) NOT NULL,
  dt_nasc     DATE NOT NULL,
  email       VARCHAR(100) NOT NULL UNIQUE
);
-- tipo_objeto
CREATE TABLE tipo_objeto (
  id_tipo_obj    SERIAL PRIMARY KEY,
  descricao         VARCHAR(100) NOT NULL
);
-- situacao_objeto
CREATE TABLE situacao_objeto (
  id_situacao_obj  SERIAL PRIMARY KEY,
  descricao           VARCHAR(100) NOT NULL
);
-- objeto
CREATE TABLE objeto (
  id_objeto           SERIAL PRIMARY KEY,
  nome                VARCHAR(45) NOT NULL,
  cod_tipo_obj     INT          NOT NULL,
  cod_situacao_obj INT          NOT NULL DEFAULT 2,
  FOREIGN KEY (cod_tipo_obj) REFERENCES tipo_objeto,
  FOREIGN KEY (cod_situacao_obj) REFERENCES situacao_objeto
);
-- manutencao
CREATE TABLE manutencao (
  id_manutencao SERIAL PRIMARY KEY,
  cod_objeto    INT NOT NULL,
  descricao     TEXT NOT NULL,
  situacao      CHAR(1) NOT NULL DEFAULT 'A' CHECK(situacao = 'A' or situacao = 'F'),
  data_entrada  TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  data_saida    TIMESTAMP DEFAULT NULL,
  FOREIGN KEY (cod_objeto) REFERENCES objeto
);
/* 
A - ativa/aberta
F - finalizada
*/
-- emprestimo
CREATE TABLE emprestimo (
  id_emprestimo   SERIAL PRIMARY KEY,
  situacao    CHAR(1) NOT NULL DEFAULT 'V'
    CHECK (situacao = 'V' or
           situacao = 'P' or
           situacao = 'C'),
  data_emissao    DATE NOT NULL DEFAULT CURRENT_DATE,
  data_vencimento DATE NOT NULL,
  data_devolucao  TIMESTAMP,
  cod_pessoa      INT NOT NULL,
  FOREIGN KEY (cod_pessoa) REFERENCES pessoa
);
/*
V - vigente
P - pendente
C - concluído
*/
-- empréstimo_objetop
CREATE TABLE emprestimo_objeto (
cod_emprestimo    INT NOT NULL,
cod_objeto        INT NOT NULL,
situacao          CHAR (1) NOT NULL DEFAULT 'E'
  CHECK (situacao = 'E' or situacao = 'D'),
data_hora_retirada  TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
data_hora_devolucao TIMESTAMP,
PRIMARY KEY (cod_emprestimo, cod_objeto),
FOREIGN KEY (cod_emprestimo) REFERENCES emprestimo,
FOREIGN KEY (cod_objeto) REFERENCES objeto
);
/*
E - emprestado
D - devolvido
*/

INSERT INTO pessoa
VALUES
       (default, 'Alessandra', '22-05-2001', 'alessandra@alessandra.com'),
       (default, 'Carla', '02-06-1996', 'carla@carla.com'),
       (default, 'Ieda', '26-10-1956', 'ieda@ieda.com'),
       (default, 'Valdemar', '01-07-1954', 'valdemar@valdemar.com'),
       (default, 'Alexandre', '02-02-1982', 'alexandre@alexandre.com'),
       (default, 'Estela', '26-04-19986', 'estela@estela.com'),
       (default, 'Luiz', '28-01-1961', 'luiz@luiz.com'),
       (default, 'Lurdes', '03-06-1967', 'ludes@lurdes.com')
;

INSERT INTO tipo_objeto
VALUES
       (default, 'eletrônico'),
       (default, 'ferramenta'),
       (default, 'vestuário'),
       (default, 'esportivo'),
       (default, 'acessório')
;

INSERT INTO situacao_objeto
VALUES
       (default, 'ativo'),
       (default, 'inativo'),
       (default, 'emprestado'),
       (default, 'manutenção'),
       (default, 'roubo'),
       (default, 'extraviado')
;

INSERT INTO objeto
VALUES
       (default, 'Computador Positivo', 1, 4),
       (default, 'Impressora HP', 1, 1),
       (default, 'Martelo', 2, 1),
       (default, 'Bola', 2, 1),
       (default, 'Camiseta', 3, 1),
       (default, 'Boné', 3, 1),
       (default, 'Carregador', 4, 3),
       (default, 'Régua', 4, 3),
       (default, 'Calculadora', 5, 3),
       (default, 'Fone de ouvido', 5, 3)
;

INSERT INTO manutencao
VALUES
       (default, 1, 'Impressora não imprime', default, default, NULL)
;

INSERT INTO emprestimo (id_emprestimo, situacao, data_emissao, data_vencimento, cod_pessoa)
VALUES
(default, 'P', '2020-05-25', '2020-06-25', 1),
(default, 'P', '2020-01-26', '2020-02-26', 2)
;

INSERT INTO emprestimo_objeto
VALUES
       (1, 5, default, default, NULL),
       (1, 6, default, default, NULL),
	   (2, 7, default, default, NULL),
       (2, 8, default, default, NULL)
;






